@@ -6,18 +6,19 @@
 # 
 # TRANSLATORS:
 # Yaron (he)
+# dotancohen (he)
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-08-09 08:35+0000
-# Last-Translator: Yaron <sh.yaron@gmail.com>
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2008-12-02 11:47+0000
+# Last-Translator: dotancohen <kubuntu@dotancohen.com>
 # Language-Team: Hebrew <he@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Launchpad-Export-Date: 2009-02-17 18:56+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -63,12 +64,12 @@ Do you want to overwrite it?' => '<b>העמוד כבר קיים</b>
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '<b>לשחזר את העמוד לגירסה השמורה?</b>
+All changes since the last saved version will be lost !' => '<b>שחזר את העמוד לגירסתו השמורה?</b>
 
 האם ברצונך לשחזר את העמוד: {page}
 לגירסה השמורה: {version} ?
 
-כל השינויים מאז גירסה זו יאבדו !',
+כל השינויים מאז השמירה האחרונה יאבדו !',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -89,7 +90,7 @@ Do you want to upgrade this notebook to the new layout?
   'Application to edit text files' => 'תוכנה לעריכת קבצי טקסט',
   'Application to open directories' => 'תוכנה לפתיחת תיקיות',
   'Application to open urls' => 'תוכנה לפתיחת קישורים',
-  'Attach _File|Attach external file' => 'צרף _קבצים|צרף קבצים חיצוניים',
+  'Attach _File|Attach external file' => 'צרף _קובץ|צרף קובץ חיצוני',
   'Attach external files' => 'צרף קבצים חיצוניים',
   'Auto-format entities' => 'עיצוב ישויות אוטומטי',
   'Auto-increment numbered lists' => 'רשימות בעלות מספרים עוקבים',
@@ -104,15 +105,20 @@ Do you want to upgrade this notebook to the new layout?
   'Bold' => 'מודגש',
   'Calen_dar|Show calendar' => 'ל_וח שנה|הצג את לוח השנה',
   'Calendar' => 'לוח שנה',
+  'Can not find application "bzr"' => 'לא ניתן למצוא את היישום "bzr"',
+  'Can not find application "{name}"' => 'לא ניתן למצוא את היישום "{name}"',
   'Can not save a version without comment' => 'לא ניתן לשמור את הגירסה בלי הערה',
   'Can not save to page: {name}' => 'לא ניתן לשמור לעמוד: {name}',
-  'Can\'t find {url}' => 'לא ניתן למצוא {url}',
+  'Can\'t find {url}' => 'לא ניתן למצוא את הכתובת {url}',
   'Cha_nge' => 'ש_נה',
   'Chars' => 'תווים',
   'Check _spelling|Spell check' => '_בדוק איות|בדוק איות',
+  'Check checkbox lists recursive' => 'בדוק האם רשימות הסימונים הן רקורסיביות',
+  'Checking a checkbox list item will also check any sub-items' => 'בודק פריט ברשימת הסימונים תבדוק גם את כל תת־הפריטים שלו',
   'Choose {app_type}' => 'בחר {app_type}',
   'Co_mpare Page...' => 'הש_ווה עמוד...',
   'Command' => 'פקודה',
+  'Comment' => 'הערה',
   'Compare this version with' => 'השווה גירסה זו עם',
   'Copy Email Address' => 'העתק כתובת דואל',
   'Copy Location|Copy location' => 'העתק מיקום|העתק מיקום',
@@ -120,6 +126,7 @@ Do you want to upgrade this notebook to the new layout?
   'Could not delete page: {name}' => 'לא ניתן למחוק עמוד: {name}',
   'Could not get annotated source for page {page}' => 'לא ניתן לאחזר את מקור הדף המפורש {page}',
   'Could not get changes for page: {page}' => 'לא ניתן לאחזר את השינויים בעמוד: {page}',
+  'Could not get changes for this notebook' => 'לא ניתן לאחזר את השינויים עבור מחברת זו',
   'Could not get file for page: {page}' => 'לא ניתן לאחזר את הקובץ עבור העמוד: {page}',
   'Could not get versions to compare' => 'לא ניתן לאחזר גירסאות להשוואה',
   'Could not initialize version control' => 'לא ניתן להפעיל את בקרת הגירסאות',
@@ -147,20 +154,22 @@ Do you want to upgrade this notebook to the new layout?
   'Edit Query' => 'ערוך שאילתה',
   'Edit _Source|Open source' => 'ער_וך מקור|פתח מקור',
   'Edit notebook' => 'ערוך מחברת',
-  'Edit text files "wiki style"' => 'ערוך קבצי טקסט "בסגנון וויקי"',
+  'Edit text files "wiki style"' => 'ערוך קבצי טקסט "בסגנון ויקי"',
   'Editing' => 'עריכה',
-  'Email client' => 'לקוח דואל',
+  'Email client' => 'לקוח דוא"ל',
   'Enabled' => 'מופעל',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => 'הפעלת בקרת הגירסאות תפעיל את מערכת בקרת הגירסאות <b>Bazaar</b>.
-נא לחץ על \'עזרה\' כדי לקרוא אודות דרישות המערכת וחלופות.',
   'Equation Editor' => 'עורך משוואות',
   'Equation Editor Log' => 'דוח עורך המשוואות',
   'Expand side pane' => 'הרחב חלונית צד',
   'Export page' => 'ייצא דף',
   'Exporting page {number}' => 'מייצא עמוד {number}',
+  'Failed to cleanup SVN working copy.' => 'כשל בנקיון העותק הפעיל מה־SVN.',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => 'שגיאה בטעינת תוסף ה־SVN,
+האם מותקנים אצלך העזרים של subversion?',
   'Failed to load plugin: {name}' => 'שגיאה בטעינת תוסף: {name}',
-  'File browser' => 'סייר הקבצים',
+  'Failed update working copy.' => 'עדכון העותק הפעיל נכשל.',
+  'File browser' => 'סייר קבצים',
   'File is not a text file: {file}' => 'הקובץ אינו קובץ טקסט: {file}',
   'Filter' => 'מסנן',
   'Find' => 'חפש',
@@ -188,6 +197,7 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Home Page' => 'דף הבית',
   'Icon' => 'סמל',
   'Id' => 'מזהה',
+  'Include all open checkboxes' => 'כלול את כל תיבות הסימון הפתוחות',
   'Index page' => 'עמוד מפתח',
   'Initial version' => 'גירסה ראשונית',
   'Insert Date' => 'הוסף תאריך',
@@ -207,21 +217,22 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'New notebook' => 'מחברת חדשה',
   'New page' => 'עמוד חדש',
   'No such directory: {name}' => 'אין כזו תיקיה: {name}',
+  'No such file or directory: {name}' => 'לא קיימים קובץ או תיקייה: {name}',
   'No such file: {file}' => 'קובץ לא קיים: {file}',
-  'No such notebook: {name}' => 'אין כזו מחברת: {name}',
+  'No such notebook: {name}' => 'לא קיימת מחברת: {name}',
   'No such page: {page}' => 'אין כלל עמוד כזה: {page}',
   'No such plugin: {name}' => 'אין תוסף כזה: {name}',
   'Normal' => 'רגיל',
   'Not Now' => 'לא כעת',
   'Not a valid page name: {name}' => 'שם לא תקני לעמוד: {name}',
-  'Not an url: {url}' => 'לא כתובת: {url}',
+  'Not an url: {url}' => 'כתובת לא חוקית: {url}',
   'Note that linking to a non-existing page
 also automatically creates a new page.' => 'שים לב שקישור לדף שאינו קיים
-גם אוטומטית יוצר דף חדש.',
+מייצר דף חדש באופן עצמאי.',
   'Notebook' => 'מחברת',
   'Notebooks' => 'מחברות',
-  'Open Document _Folder|Open document folder' => 'פתח את _תיקיית המסמך|פתח תיקיית המסמך',
-  'Open Document _Root|Open document root' => 'פתח את _שורש המסמך|פתח שורש המסמך',
+  'Open Document _Folder|Open document folder' => 'פתח _תיקיית המסמך|פתח תיקיית המסמך',
+  'Open Document _Root|Open document root' => 'פתח _שורש המסמך|פתח שורש המסמך',
   'Open _Directory' => 'פתח ת_יקיה',
   'Open notebook' => 'פתח מחברת',
   'Other...' => 'אחר...',
@@ -230,8 +241,9 @@ also automatically creates a new page.' => 'שים לב שקישור לדף שא
   'P_athbar type|' => 'ס_וג סרגל הנתיב|',
   'Page' => 'עמוד',
   'Page Editable|Page editable' => 'הדף ניתן לעריכה|הדף ניתן לעריכה',
-  'Page name' => 'שם העמוד',
+  'Page name' => 'שם עמוד',
   'Pages' => 'עמודים',
+  'Password' => 'סיסמה',
   'Please enter a comment for this version' => 'נא הזינו הערה לגירסה זו',
   'Please enter a name to save a copy of page: {page}' => 'נא הזן שם כדי לשמור עותק של העמוד: {page}',
   'Please enter a {app_type}' => 'נא הזן {app_type}',
@@ -241,6 +253,9 @@ For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'יש להזין לפחות את התיקייה לאיחסון הדפים שלך.
 למחברת חדשה יש להשתמש בתיקייה ריקה.
 לדוגמה תיקייה בשם "הערות" בתיקיית הבית שלך.',
+  'Please provide the password for
+{path}' => 'נא ספק את הסיסמה עבור
+{path}',
   'Please select a notebook first' => 'נא בחרו מחברת תחילה',
   'Please select a version first' => 'נא בחר גירסה תחילה',
   'Plugin already loaded: {name}' => 'התוסף כבר נטען: {name}',
@@ -259,12 +274,15 @@ For example a "Notes" directory in your home dir.' => 'יש להזין לפחו
   'Rename to' => 'שינוי השם אל',
   'Replace _all' => 'החלף ה_כל',
   'Replace with' => 'החלף עם',
-  'S_ave Version...|Save Version' => 'שמור _גירסה...|שמור גירסה',
+  'SVN cleanup|Cleanup SVN working copy' => 'ניקוי SVN|נקה עותק פעיל של SVN',
+  'SVN commit|Commit notebook to SVN repository' => 'מסירת SVN|מסירת המחברת למאגר SVN',
+  'SVN update|Update notebook from SVN repository' => 'עדכון SVN|עדכון המחברת ממאגר SVN',
+  'S_ave Version...|Save Version' => 'ש_מור גירסה...|שמור גירסה',
   'Save Copy' => 'שמור עותק',
   'Save version' => 'שמור גירסה',
   'Scanning tree ...' => 'סורק את העץ...',
   'Search' => 'חפש',
-  'Search _Backlinks...|Search Back links' => 'חפש _קישורי חזרה...|חפש בקישורי החזרה',
+  'Search _Backlinks...|Search Back links' => 'חפש ב_קישורי חזרה...|חפש בקישורי החזרה',
   'Select File' => 'בחר קובץ',
   'Select Folder' => 'בחר תיקייה',
   'Send To...' => 'שלח אל...',
@@ -294,7 +312,12 @@ is missing. Can not edit equation.' => 'המשוואה לתמונה: {path}
 404',
   'This page does not have a document folder' => 'לעמוד זה אין תיקיית מסמך',
   'This page does not have a source' => 'לדף זה אין מקור',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => 'עמוד זה עודכן במאגר.
+אנא עדכן את העותק הפעיל שלך (כלים ->עדכון SVN).',
   'To_day|Today' => 'ה_יום|היום',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => 'סמן/בטל תיבת בחירה \'V\'|סמן/בטל תיבת בחירה',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => 'סמן/בטל תיבת בחירה \'X\'|סמן/בטל תיבת בחירה',
   'Underline' => 'קו תחתי',
   'Updating links' => 'מעדכן קישורים',
   'Updating links in {name}' => 'מעדכן קישורים תחת {name}',
@@ -319,7 +342,10 @@ is missing. Can not edit equation.' => 'המשוואה לתמונה: {path}
   'Word Count' => 'ספירת המילים',
   'Words' => 'מילים',
   'You can add rules to your search query below' => 'תוכל להוסיף כללים לשאילתת החיפוש שלך להלן',
-  'You have no {app_type} configured' => 'לא מוגדרות אצלך כל {app_type}',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => 'תוכל להשתמש במערכות בקרת הגירסאות <b>Bazaar</b> או <b>Subversion</b>.
+אנא לחץ על \'עזרה\' כדי לקרוא אודות דרישות המערכת.',
+  'You have no {app_type} configured' => 'לא מוגדרות אצלך {app_type}',
   'You need to restart the application
 for plugin changes to take effect.' => 'עליך לאתחל את התוכנה על מנת
 שהשינויים בתוספים יכנסו לתוקף.',
@@ -330,8 +356,8 @@ for plugin changes to take effect.' => 'עליך לאתחל את התוכנה ע
   '_Back|Go page back' => 'ח_זרה|חזור לעמוד הקודם',
   '_Bold|Bold' => '_מודגש|מודגש',
   '_Browse...' => '_עיין...',
-  '_Bugs|Bugs' => '_תקלות|תקלות',
-  '_Child|Go to child page' => '_צאצא|עבור לעמוד הצאצא',
+  '_Bugs|Bugs' => '_שגיאות|שגיאות',
+  '_Child|Go to child page' => '_צאצא|עבור לעמוד צאצא',
   '_Close|Close window' => '_סגור|סגור את החלון',
   '_Contents|Help contents' => 'ת_כנים|תכני העזרה',
   '_Copy Page...|Copy page' => 'ה_עתק עמוד...|העתק עמוד',
@@ -340,6 +366,7 @@ for plugin changes to take effect.' => 'עליך לאתחל את התוכנה ע
   '_Delete Page|Delete page' => 'מחק _עמוד|מחק עמוד',
   '_Delete|Delete' => '_מחק|מחק',
   '_Discard changes' => 'ה_תעלם מהשינויים',
+  '_Edit' => '_ערוך',
   '_Edit Equation' => 'ע_רוך משוואה',
   '_Edit Link' => '_ערוך קישור',
   '_Edit Link...|Edit link' => '_ערוך קישור...|ערוך קישור',
@@ -354,7 +381,7 @@ for plugin changes to take effect.' => 'עליך לאתחל את התוכנה ע
   '_History|.' => 'הי_סטוריה|.',
   '_Home|Go home' => '_בית|גש לעמוד הבית',
   '_Image...|Insert image' => '__תמונה...|הוסף תמונה',
-  '_Index|Show index' => '_מפתח הנושאים|הצג את המפתח',
+  '_Index|Show index' => '_מפתח הנושאים|הצג את מפתח הנושאים',
   '_Insert' => 'ה_וסף',
   '_Insert|' => '_הוספה|',
   '_Italic|Italic' => '_נטוי|נטוי',
@@ -386,7 +413,7 @@ for plugin changes to take effect.' => 'עליך לאתחל את התוכנה ע
   '_Redo|Redo' => '_בצע שוב|בצע שוב',
   '_Reload|Reload page' => '_רענן|רענן עמוד',
   '_Rename' => '_שנה שם',
-  '_Rename Page...|Rename page' => 'ש_נה שם העמוד...|שנה את שם העמוד',
+  '_Rename Page...|Rename page' => 'ש_נה שם העמוד...|שנה שם העמוד',
   '_Replace' => 'ה_חלף',
   '_Replace...|Find and Replace' => 'ה_חלף|חפש והחלף',
   '_Reset' => '_איפוס',
@@ -401,7 +428,7 @@ for plugin changes to take effect.' => 'עליך לאתחל את התוכנה ע
   '_Statusbar|Show statusbar' => '_שורת מצה|הצג את שורת המצב',
   '_TODO List...|Open TODO List' => '_רשימת מטלות...|פתח רשימת מטלות',
   '_Today' => 'ה_יום',
-  '_Toolbar|Show toolbar' => '_סרגל הכלים|סרגל כלים',
+  '_Toolbar|Show toolbar' => '_סרגל כלים|הצג את סרגל הכלים',
   '_Tools|' => '_כלים|',
   '_Underline|Underline' => '_קו תחתי|קו תחתי',
   '_Undo|Undo' => '_בטל|בטל',
@@ -417,7 +444,7 @@ for plugin changes to take effect.' => 'עליך לאתחל את התוכנה ע
   'other...' => 'אחר...',
   '{name}_(Copy)' => '{name}_(עותק)',
   '{number} _Back link' => [
-    '_קישור חזרה {number}',
+    '_קישורי חזרה {number}',
     '{number} _קישורי חזרה'
   ],
   '{number} item total' => [
