@@ -14,15 +14,15 @@
 # 
 # Project-Id-Version: Zim 0.23
 # Report-Msgid-Bugs-To: 
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-08-06 08:07+0000
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2008-10-29 08:23+0000
 # Last-Translator: Jaap Karssenberg <pardus@cpan.org>
 # Language-Team: 
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Launchpad-Export-Date: 2008-11-09 09:05+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -67,12 +67,12 @@ bestaat al. Wilt u deze overschrijven?',
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '<b>Opgeslagen versie herstellen?</b>
+All changes since the last saved version will be lost !' => '<b>Vorige versie herstellen?</b>
 
 Wilt u de pagina: {page}
 herstellen naar versie: {version} ?
 
-Alle wijzigingen sinds deze versie zullen verloren gaan!',
+Alle wijzigingen sinds de laatste opgeslagen versie zullen verloren gaan!',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -109,15 +109,20 @@ Wilt u dit notitieboek omzetten naar het nieuwe formaat ?
   'Bold' => 'Vet',
   'Calen_dar|Show calendar' => 'Kalen_der|Kalender tonen',
   'Calendar' => 'Kalender',
+  'Can not find application "bzr"' => 'Kan applicatie "bzr" niet vinden',
+  'Can not find application "{name}"' => 'Kan applicatie "{name}" niet vinden',
   'Can not save a version without comment' => 'Kan geen versie opslaan zonder omschrijving',
   'Can not save to page: {name}' => 'Kan niet opslaan naar: {name}',
   'Can\'t find {url}' => 'Kan {url} niet vinden',
   'Cha_nge' => '_Wijzigen',
   'Chars' => 'Letters',
   'Check _spelling|Spell check' => '_Spelling controlleren|Spelling controlleren',
+  'Check checkbox lists recursive' => 'Markeer checkbox lists recursief',
+  'Checking a checkbox list item will also check any sub-items' => 'Wanneer u een checkbox markeert worden ook alle sub-items gemarkeerd',
   'Choose {app_type}' => 'Kies {app_type}',
   'Co_mpare Page...' => '_Vergelijk pagina...',
   'Command' => 'Programma',
+  'Comment' => 'Beschrijving',
   'Compare this version with' => 'Deze versie vergelijken met',
   'Copy Email Address' => 'Email Adres Kopiëren',
   'Copy Location|Copy location' => 'Locatie kopieren|Locatie kopieren',
@@ -125,6 +130,7 @@ Wilt u dit notitieboek omzetten naar het nieuwe formaat ?
   'Could not delete page: {name}' => 'Kan pagina niet verwijderen: {name}',
   'Could not get annotated source for page {page}' => 'Kan aantekeningen niet vinden voor pagina: {page}',
   'Could not get changes for page: {page}' => 'Kan geen veranderingen vinden voor pagina: {page}',
+  'Could not get changes for this notebook' => 'Kan veranderingen voor dit notitieboek niet vinden',
   'Could not get file for page: {page}' => 'Kan geen bestand vinden voor pagina: {page}',
   'Could not get versions to compare' => 'Kan de versies om te vergelijken niet vinden',
   'Could not initialize version control' => 'Kan versie beheer niet inschakelen',
@@ -156,15 +162,17 @@ Wilt u dit notitieboek omzetten naar het nieuwe formaat ?
   'Editing' => 'Bewerken',
   'Email client' => 'Email programma',
   'Enabled' => 'In gebruik',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => 'Versie beheer maakt gebruik van het <b>Bazaar</b> Version Control System.
-Klik op \'hulp\' om de systeem eisen en alternatieven te bekijken.',
   'Equation Editor' => 'Formule Bewerken',
   'Equation Editor Log' => 'Formule Log',
   'Expand side pane' => 'Zij-paneel uitklappen',
   'Export page' => 'Pagina Exporteren',
   'Exporting page {number}' => 'Pagina {number} aan het exporteren',
+  'Failed to cleanup SVN working copy.' => 'Cleanup van kopie mislukt',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => 'Laden van de SVN plugin mislukt,
+heeft u de subversion applicatie geinstalleerd?',
   'Failed to load plugin: {name}' => 'Kan plugin niet laden: {name}',
+  'Failed update working copy.' => 'Update uit archief mislukt',
   'File browser' => 'Bestandsbrowser',
   'File is not a text file: {file}' => 'Bestand is geen tekst bestand: {file}',
   'Filter' => 'Filter',
@@ -193,6 +201,7 @@ Klik op \'hulp\' om de systeem eisen en alternatieven te bekijken.',
   'Home Page' => 'Start Pagina',
   'Icon' => 'Icoon',
   'Id' => 'Id',
+  'Include all open checkboxes' => 'Laat alle open checkboxes zien',
   'Index page' => 'Index pagina',
   'Initial version' => 'Eerste versie',
   'Insert Date' => 'Datum invoegen',
@@ -212,6 +221,7 @@ Klik op \'hulp\' om de systeem eisen en alternatieven te bekijken.',
   'New notebook' => 'Nieuw notitieboek',
   'New page' => 'Nieuwe pagina',
   'No such directory: {name}' => 'Map bestaat niet: {name}',
+  'No such file or directory: {name}' => 'Bestand of folder bestaat niet: {name}',
   'No such file: {file}' => 'Bestand niet gevonden: {file}',
   'No such notebook: {name}' => 'Notitieboek niet gevonden: {name}',
   'No such page: {page}' => 'Pagina bestaat niet: {page}',
@@ -237,6 +247,7 @@ kan u ook een nieuwe pagina aanmaken.',
   'Page Editable|Page editable' => 'Pagina te wijzigen|Pagina te wijzigen',
   'Page name' => 'Pagina naam',
   'Pages' => 'Paginas',
+  'Password' => 'Wachtwoord',
   'Please enter a comment for this version' => 'Geef een korte omschrijving voor deze versie',
   'Please enter a name to save a copy of page: {page}' => 'Geef een naam op om een kopie op te slaan van: {page}',
   'Please enter a {app_type}' => 'Geef een commando om een {app_type} te starten',
@@ -246,6 +257,9 @@ For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'U dient een map aan te geven om uw notities op te slaan.
 Voor een nieuw notitieboek dien dit een lege map te zijn.
 Bijvoorbeeld een map "Notes" in uw persoonlijke map.',
+  'Please provide the password for
+{path}' => 'Geef wachtwoord voor:
+{path}',
   'Please select a notebook first' => 'Selecteer eerst een notitieboek',
   'Please select a version first' => 'Geef eerst een versie op',
   'Plugin already loaded: {name}' => 'Plugin is al geladen: {name}',
@@ -264,6 +278,9 @@ Bijvoorbeeld een map "Notes" in uw persoonlijke map.',
   'Rename to' => 'Hernoemen naar',
   'Replace _all' => '_Alles vervangen',
   'Replace with' => 'Vervangen door',
+  'SVN cleanup|Cleanup SVN working copy' => 'SVN cleanup|Cleanup SVN archief kopie',
+  'SVN commit|Commit notebook to SVN repository' => 'SVN commit|Commit notitieboek naar het SVN archief',
+  'SVN update|Update notebook from SVN repository' => 'SVN update|Update notitieboek uit het SVN archief',
   'S_ave Version...|Save Version' => 'V_ersie Opslaan...|Versie opslaan',
   'Save Copy' => 'Kopie Opslaan',
   'Save version' => 'Versie opslaan',
@@ -299,7 +316,12 @@ mist. Kan de formule niet wijzigen.',
 404',
   'This page does not have a document folder' => 'Deze pagina heeft geen documenten folder',
   'This page does not have a source' => 'Deze pagina heeft geen bron text',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => 'Deze pagina is veranderd in het archief.
+U dient uw kopie to updaten (Tools -> SVN update).',
   'To_day|Today' => 'Van_daag|Vandaag',
+  'Toggle Checkbox \'V\'|Toggle checkbox' => 'Markeer checkbox "V"|Markeer checkbox "V"',
+  'Toggle Checkbox \'X\'|Toggle checkbox' => 'Markeer checkbox "V"|Markeer checkbox "V"',
   'Underline' => 'Onderstreept',
   'Updating links' => 'Links aanpassen',
   'Updating links in {name}' => 'Links aan het aanpassen in {name}',
@@ -324,6 +346,9 @@ mist. Kan de formule niet wijzigen.',
   'Word Count' => 'Woorden Tellen',
   'Words' => 'Woorden',
   'You can add rules to your search query below' => 'U kunt hieronder regels toevoegen aan de zoekterm',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => 'U kunt kiezen tussen de <b>Bazaar</b> en <b>Subversion</b> Versie Beheer Systemen.
+Klik op \'hulp\' voor meer informatie over de systeem eisen.',
   'You have no {app_type} configured' => 'Geen {app_type} geconfigureerd',
   'You need to restart the application
 for plugin changes to take effect.' => 'U dient dit programma opnieuw te starten
@@ -345,6 +370,7 @@ voordat nieuwe plugins geladen worden.',
   '_Delete Page|Delete page' => 'Pagina Verwijderen|Pagina verwijderen',
   '_Delete|Delete' => '_Wissen|Wissen',
   '_Discard changes' => 'Wijzigingen _vergeten',
+  '_Edit' => '_Bewerken',
   '_Edit Equation' => 'Formule Be_werken',
   '_Edit Link' => 'Link be_werken',
   '_Edit Link...|Edit link' => 'Link _Wijzigen|Link wijzigen',
